@@ -1,3 +1,3 @@
 import imp
-from helper import Fiscal_Helper
+from .helper import Fiscal_Helper
 fiscal = Fiscal_Helper()
\ No newline at end of file
