@@ -3,7 +3,7 @@ import pandas as pd
 class Fiscal_Helper:
 
     def __init__(self):
-        self.calendar = pd.read_csv('./fiscal_calendar.csv')
+        self.calendar = pd.read_csv('./fiscal_calendar_helper/fiscal_calendar.csv')
 
         # create a list of week_ids
         weeks = self.calendar['week_id']
@@ -37,4 +37,16 @@ class Fiscal_Helper:
         else:
             raise Exception(f"Input type should be 'YYYY_WW' for week ID and 'YYYY_MM_DD' for date_id")
 
-        return out_str
\ No newline at end of file
+        return out_str
+
+    # Converts one fiscal time period to another
+    def convert(self, inp_str: str, inp_type: str, out_type: str):
+            if inp_type == 'week':
+                if self.is_valid_week(inp_str):
+                    bob = "Do the translation"
+            return True
+
+    def is_valid_fiscal(self, inp_str: str, inp_type: str):
+
+        return True
+
